@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# pylint: disable=R1710
+# pylint: disable=R1710, R0914, E1121
 
 from __future__ import (unicode_literals, division,
                         absolute_import, print_function)
@@ -8,6 +8,9 @@ from __future__ import (unicode_literals, division,
 from powerline.segments import Segment, with_docstring
 from powerline.theme import requires_segment_info, requires_filesystem_watcher
 from kubernetes import config
+from kubernetes.config.config_exception import ConfigException
+from kubernetes.client import VersionApi
+from urllib3.exceptions import MaxRetryError
 
 
 @requires_filesystem_watcher
@@ -16,7 +19,7 @@ class K8SStatusSegment(Segment):
     divider_highlight_group = None
 
     @staticmethod
-    def build_segments(context, namespace, user, contextalert, namespacealert):
+    def build_segments(context, namespace, user, version, contextalert, namespacealert):
         segments = [{'contents': ('\U00002388 {}').format(
             context), 'highlight_groups': [contextalert]}]
 
@@ -34,10 +37,18 @@ class K8SStatusSegment(Segment):
                 'divider_highlight_group': 'k8sstatus:divider'
             })
 
+        if version and version.lower():
+            segments.append({
+                'contents': version,
+                'highlight_groups': ['k8sstatus_version'],
+                'divider_highlight_group': 'k8sstatus:divider'
+            })
+
         return segments
 
     def __call__(self, pl, segment_info, create_watcher=None, context_alert: list = None,
-                 namespace_alert: list = None, show_namespace=False, show_user=False):
+                 namespace_alert: list = None, show_namespace=False, show_user=False,
+                 show_version=False):
 
         if context_alert is None:
             context_alert = []
@@ -55,8 +66,6 @@ class K8SStatusSegment(Segment):
             contexts, active_context = config.list_kube_config_contexts()
         except TypeError:
             return
-        except config.config_exception.ConfigException:
-            return
 
         if not contexts:
             return
@@ -80,12 +89,20 @@ class K8SStatusSegment(Segment):
         else:
             namespace = 'default'
 
+        user = None
         if show_user:
             user = active_context['context']['user']
-        else:
-            user = None
 
-        return self.build_segments(context, namespace, user, contextstatus, namespacestatus)
+        version = None
+        if show_version:
+            try:
+                version = VersionApi(
+                    config.load_kube_config()).get_code().git_version
+            except (ConnectionRefusedError, MaxRetryError, ConfigException):
+                version = None
+
+        return self.build_segments(context, namespace, user, version,
+                                   contextstatus, namespacestatus)
 
 
 k8sstatus = with_docstring(
